@@ -38,7 +38,7 @@ class EditSubscriptionCommand : public Command
     Q_OBJECT
 public:
     explicit EditSubscriptionCommand(QObject *parent = nullptr);
-    ~EditSubscriptionCommand();
+    ~EditSubscriptionCommand() override;
 
     void setSubscription(const QSharedPointer<FeedList> &feedList, int subId);
     int subscriptionId() const;
@@ -54,7 +54,6 @@ private:
 private:
     class Private;
     Private *const d;
-    Q_PRIVATE_SLOT(d, void startEdit())
 };
 }
 
