@@ -39,7 +39,7 @@ class ExpireItemsCommand : public Command
     Q_OBJECT
 public:
     explicit ExpireItemsCommand(QObject *parent = nullptr);
-    ~ExpireItemsCommand();
+    ~ExpireItemsCommand() override;
 
     void setFeedList(const QWeakPointer<FeedList> &feedList);
     QWeakPointer<FeedList> feedList() const;
@@ -54,8 +54,6 @@ private:
 private:
     class Private;
     Private *const d;
-    Q_PRIVATE_SLOT(d, void createDeleteJobs())
-    Q_PRIVATE_SLOT(d, void jobFinished(KJob *))
 };
 }
 
