@@ -43,7 +43,7 @@ class LoadFeedListCommand : public Command
     Q_OBJECT
 public:
     explicit LoadFeedListCommand(QObject *parent = nullptr);
-    ~LoadFeedListCommand();
+    ~LoadFeedListCommand() override;
 
     void setFileName(const QString &fileName);
     void setDefaultFeedList(const QDomDocument &doc);
@@ -59,7 +59,6 @@ private:
 private:
     class Private;
     Private *const d;
-    Q_PRIVATE_SLOT(d, void doLoad())
 };
 }
 
