@@ -27,6 +27,7 @@
 
 #include <feed.h>
 
+#include <QDateTime>
 #include <QHash>
 #include <QList>
 #include <QMap>
@@ -43,7 +44,7 @@ public:
     public:
         Entry() :
             status(0)
-          , pubDate(0)
+          , pubDate()
           , hash(0)
           , guidIsHash(false)
           , guidIsPermaLink(false)
@@ -51,8 +52,6 @@ public:
         }
 
         StorageDummyImpl *mainStorage = nullptr;
-        QList<Category> categories;
-        QStringList tags;
         QString enclosureUrl;
         QString enclosureType;
         QString title;
@@ -62,11 +61,9 @@ public:
         QString authorName;
         QString authorUri;
         QString authorEMail;
-        QString commentsLink;
-        int comments;
         int status;
         int enclosureLength;
-        uint pubDate;
+        QDateTime pubDate;
         uint hash;
         bool guidIsHash = false;
         bool guidIsPermaLink = false;
@@ -75,23 +72,10 @@ public:
 
     QHash<QString, Entry> entries;
 
-    // all tags occurring in the feed
-    QStringList tags;
-
-    // tag -> articles index
-    QHash<QString, QStringList> taggedArticles;
-
-    QList<Category> categories;
-    QMap<Akregator::Backend::Category, QStringList> categorizedArticles;
-
-    Storage *mainStorage;
+    StorageDummyImpl *mainStorage;
     QString url;
 };
 
-void FeedStorageDummyImpl::convertOldArchive()
-{
-}
-
 FeedStorageDummyImpl::FeedStorageDummyImpl(const QString &url, StorageDummyImpl *main) : d(new FeedStorageDummyImplPrivate)
 {
     d->url = url;
@@ -104,18 +88,6 @@ FeedStorageDummyImpl::~FeedStorageDummyImpl()
     d = nullptr;
 }
 
-void FeedStorageDummyImpl::commit()
-{
-}
-
-void FeedStorageDummyImpl::rollback()
-{
-}
-
-void FeedStorageDummyImpl::close()
-{
-}
-
 int FeedStorageDummyImpl::unread() const
 {
     return d->mainStorage->unreadFor(d->url);
@@ -136,24 +108,19 @@ void FeedStorageDummyImpl::setTotalCount(int total)
     d->mainStorage->setTotalCountFor(d->url, total);
 }
 
-int FeedStorageDummyImpl::lastFetch() const
+QDateTime FeedStorageDummyImpl::lastFetch() const
 {
     return d->mainStorage->lastFetchFor(d->url);
 }
 
-void FeedStorageDummyImpl::setLastFetch(int lastFetch)
+void FeedStorageDummyImpl::setLastFetch(const QDateTime &lastFetch)
 {
     d->mainStorage->setLastFetchFor(d->url, lastFetch);
 }
 
-QStringList FeedStorageDummyImpl::articles(const QString &tag) const
+QStringList FeedStorageDummyImpl::articles() const
 {
-    return tag.isNull() ? QStringList(d->entries.keys()) : d->taggedArticles.value(tag);
-}
-
-QStringList FeedStorageDummyImpl::articles(const Category &cat) const
-{
-    return d->categorizedArticles.value(cat);
+    return QStringList(d->entries.keys());
 }
 
 void FeedStorageDummyImpl::addEntry(const QString &guid)
@@ -180,16 +147,6 @@ void FeedStorageDummyImpl::deleteArticle(const QString &guid)
     d->entries.remove(guid);
 }
 
-int FeedStorageDummyImpl::comments(const QString &guid) const
-{
-    return contains(guid) ? d->entries[guid].comments : 0;
-}
-
-QString FeedStorageDummyImpl::commentsLink(const QString &guid) const
-{
-    return contains(guid) ? d->entries[guid].commentsLink : QString();
-}
-
 bool FeedStorageDummyImpl::guidIsHash(const QString &guid) const
 {
     return contains(guid) ? d->entries[guid].guidIsHash : false;
@@ -213,33 +170,10 @@ void FeedStorageDummyImpl::setDeleted(const QString &guid)
 
     FeedStorageDummyImplPrivate::Entry entry = d->entries[guid];
 
-    // remove article from tag->article index
-    QStringList::ConstIterator it = entry.tags.constBegin();
-    QStringList::ConstIterator end = entry.tags.constEnd();
-
-    for (; it != end; ++it) {
-        d->taggedArticles[*it].removeAll(guid);
-        if (d->taggedArticles[*it].isEmpty()) {
-            d->tags.removeAll(*it);
-        }
-    }
-
-    // remove article from tag->category index
-    QList<Category>::ConstIterator it2 = entry.categories.constBegin();
-    QList<Category>::ConstIterator end2 = entry.categories.constEnd();
-
-    for (; it2 != end2; ++it2) {
-        d->categorizedArticles[*it2].removeAll(guid);
-        if (d->categorizedArticles[*it2].isEmpty()) {
-            d->categories.removeAll(*it2);
-        }
-    }
-
     entry.description.clear();
     entry.content.clear();
     entry.title.clear();
     entry.link.clear();
-    entry.commentsLink.clear();
 }
 
 QString FeedStorageDummyImpl::link(const QString &guid) const
@@ -247,9 +181,9 @@ QString FeedStorageDummyImpl::link(const QString &guid) const
     return contains(guid) ? d->entries[guid].link : QString();
 }
 
-uint FeedStorageDummyImpl::pubDate(const QString &guid) const
+QDateTime FeedStorageDummyImpl::pubDate(const QString &guid) const
 {
-    return contains(guid) ? d->entries[guid].pubDate : 0;
+    return contains(guid) ? d->entries[guid].pubDate : QDateTime();
 }
 
 int FeedStorageDummyImpl::status(const QString &guid) const
@@ -264,6 +198,17 @@ void FeedStorageDummyImpl::setStatus(const QString &guid, int status)
     }
 }
 
+void FeedStorageDummyImpl::article(const QString &guid, uint &hash, QString &title, int &status, QDateTime &pubDate) const
+{
+    if (contains(guid)) {
+        auto &entry = d->entries[guid];
+        hash = entry.hash;
+        title = entry.title;
+        status = entry.status;
+        pubDate = entry.pubDate;
+    }
+}
+
 QString FeedStorageDummyImpl::title(const QString &guid) const
 {
     return contains(guid) ? d->entries[guid].title : QString();
@@ -294,7 +239,7 @@ QString FeedStorageDummyImpl::authorEMail(const QString &guid) const
     return contains(guid) ? d->entries[guid].authorEMail : QString();
 }
 
-void FeedStorageDummyImpl::setPubDate(const QString &guid, uint pubdate)
+void FeedStorageDummyImpl::setPubDate(const QString &guid, const QDateTime &pubdate)
 {
     if (contains(guid)) {
         d->entries[guid].pubDate = pubdate;
@@ -336,13 +281,6 @@ void FeedStorageDummyImpl::setDescription(const QString &guid, const QString &de
     }
 }
 
-void FeedStorageDummyImpl::setCommentsLink(const QString &guid, const QString &commentsLink)
-{
-    if (contains(guid)) {
-        d->entries[guid].commentsLink = commentsLink;
-    }
-}
-
 void FeedStorageDummyImpl::setContent(const QString &guid, const QString &content)
 {
     if (contains(guid)) {
@@ -371,13 +309,6 @@ void FeedStorageDummyImpl::setAuthorEMail(const QString &guid, const QString &au
     }
 }
 
-void FeedStorageDummyImpl::setComments(const QString &guid, int comments)
-{
-    if (contains(guid)) {
-        d->entries[guid].comments = comments;
-    }
-}
-
 void FeedStorageDummyImpl::setGuidIsPermaLink(const QString &guid, bool isPermaLink)
 {
     if (contains(guid)) {
@@ -385,104 +316,6 @@ void FeedStorageDummyImpl::setGuidIsPermaLink(const QString &guid, bool isPermaL
     }
 }
 
-void FeedStorageDummyImpl::addTag(const QString &guid, const QString &tag)
-{
-    if (contains(guid)) {
-        d->entries[guid].tags.append(tag);
-        if (!d->taggedArticles[tag].contains(guid)) {
-            d->taggedArticles[tag].append(guid);
-        }
-        if (!d->tags.contains(tag)) {
-            d->tags.append(tag);
-        }
-    }
-}
-
-void FeedStorageDummyImpl::addCategory(const QString &guid, const Category &cat)
-{
-    if (!contains(guid)) {
-        return;
-    }
-
-    d->entries[guid].categories.append(cat);
-
-    if (d->categorizedArticles[cat].isEmpty()) {
-        d->categories.append(cat);
-    }
-    d->categorizedArticles[cat].append(guid);
-}
-
-QList<Category> FeedStorageDummyImpl::categories(const QString &guid) const
-{
-    if (!guid.isNull()) {
-        return contains(guid) ? d->entries[guid].categories : QList<Category>();
-    } else {
-        return d->categories;
-    }
-}
-
-void FeedStorageDummyImpl::removeTag(const QString &guid, const QString &tag)
-{
-    if (contains(guid)) {
-        d->entries[guid].tags.removeAll(tag);
-        d->taggedArticles[tag].removeAll(guid);
-        if (d->taggedArticles[tag].isEmpty()) {
-            d->tags.removeAll(tag);
-        }
-    }
-}
-
-QStringList FeedStorageDummyImpl::tags(const QString &guid) const
-{
-    if (!guid.isNull()) {
-        return contains(guid) ? d->entries[guid].tags : QStringList();
-    } else {
-        return d->tags;
-    }
-}
-
-void FeedStorageDummyImpl::add(FeedStorage *source)
-{
-    QStringList articles = source->articles();
-    for (QStringList::ConstIterator it = articles.constBegin(); it != articles.constEnd(); ++it) {
-        copyArticle(*it, source);
-    }
-    setUnread(source->unread());
-    setLastFetch(source->lastFetch());
-    setTotalCount(source->totalCount());
-}
-
-void FeedStorageDummyImpl::copyArticle(const QString &guid, FeedStorage *source)
-{
-    if (!contains(guid)) {
-        addEntry(guid);
-    }
-
-    setComments(guid, source->comments(guid));
-    setCommentsLink(guid, source->commentsLink(guid));
-    setDescription(guid, source->description(guid));
-    setContent(guid, source->content(guid));
-    setGuidIsHash(guid, source->guidIsHash(guid));
-    setGuidIsPermaLink(guid, source->guidIsPermaLink(guid));
-    setHash(guid, source->hash(guid));
-    setLink(guid, source->link(guid));
-    setPubDate(guid, source->pubDate(guid));
-    setStatus(guid, source->status(guid));
-    setTitle(guid, source->title(guid));
-    QStringList tags = source->tags(guid);
-
-    for (QStringList::ConstIterator it = tags.constBegin(); it != tags.constEnd(); ++it) {
-        addTag(guid, *it);
-    }
-}
-
-void FeedStorageDummyImpl::clear()
-{
-    d->entries.clear();
-    setUnread(0);
-    setTotalCount(0);
-}
-
 void FeedStorageDummyImpl::setEnclosure(const QString &guid, const QString &url, const QString &type, int length)
 {
     if (contains(guid)) {
