@@ -35,27 +35,18 @@ public:
     FeedStorageDummyImpl(const QString &url, StorageDummyImpl *main);
     ~FeedStorageDummyImpl() override;
 
-    void add(FeedStorage *source) override;
-    void copyArticle(const QString &guid, FeedStorage *source) override;
-
-    void clear() override;
     int unread() const override;
     void setUnread(int unread) override;
     int totalCount() const override;
-    int lastFetch() const override;
-    void setLastFetch(int lastFetch) override;
+    QDateTime lastFetch() const override;
+    void setLastFetch(const QDateTime &lastFetch) override;
 
-    QStringList articles(const QString &tag = QString()) const override;
-
-    QStringList articles(const Category &cat) const override;
+    QStringList articles() const override;
 
+    void article(const QString &guid, uint &hash, QString &title, int &status, QDateTime &pubDate) const override;
     bool contains(const QString &guid) const override;
     void addEntry(const QString &guid) override;
     void deleteArticle(const QString &guid) override;
-    int comments(const QString &guid) const override;
-    QString commentsLink(const QString &guid) const override;
-    void setCommentsLink(const QString &guid, const QString &commentsLink) override;
-    void setComments(const QString &guid, int comments) override;
     bool guidIsHash(const QString &guid) const override;
     void setGuidIsHash(const QString &guid, bool isHash) override;
     bool guidIsPermaLink(const QString &guid) const override;
@@ -65,8 +56,8 @@ public:
     void setDeleted(const QString &guid) override;
     QString link(const QString &guid) const override;
     void setLink(const QString &guid, const QString &link) override;
-    uint pubDate(const QString &guid) const override;
-    void setPubDate(const QString &guid, uint pubdate) override;
+    QDateTime pubDate(const QString &guid) const override;
+    void setPubDate(const QString &guid, const QDateTime & pubdate) override;
     int status(const QString &guid) const override;
     void setStatus(const QString &guid, int status) override;
     QString title(const QString &guid) const override;
@@ -75,17 +66,11 @@ public:
     void setDescription(const QString &guid, const QString &description) override;
     QString content(const QString &guid) const override;
     void setContent(const QString &guid, const QString &content) override;
-    void addTag(const QString &guid, const QString &tag) override;
-    void removeTag(const QString &guid, const QString &tag) override;
-    QStringList tags(const QString &guid = QString()) const override;
 
     void setEnclosure(const QString &guid, const QString &url, const QString &type, int length) override;
     void removeEnclosure(const QString &guid) override;
     void enclosure(const QString &guid, bool &hasEnclosure, QString &url, QString &type, int &length) const override;
 
-    void addCategory(const QString &guid, const Category &category) override;
-    QList<Category> categories(const QString &guid = QString()) const override;
-
     void setAuthorName(const QString &guid, const QString &authorName) override;
     void setAuthorUri(const QString &guid, const QString &authorUri) override;
     void setAuthorEMail(const QString &guid, const QString &authorEMail) override;
@@ -94,11 +79,6 @@ public:
     QString authorUri(const QString &guid) const override;
     QString authorEMail(const QString &guid) const override;
 
-    void close() override;
-    void commit() override;
-    void rollback() override;
-
-    void convertOldArchive() override;
 private:
     /** finds article by guid, returns -1 if not in archive **/
     int findArticle(const QString &guid) const;
