@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ class AKREGATORPART_EXPORT WebEngineFrame : public Frame
     Q_OBJECT
 public:
     explicit WebEngineFrame(KActionCollection *ac, QWidget *parent = nullptr);
-    ~WebEngineFrame();
+    ~WebEngineFrame() override;
 
     QUrl url() const override;
     bool openUrl(const OpenUrlRequest &request) override;
