@@ -82,12 +82,12 @@ MainWindow::MainWindow(QWidget *parent)
     statusBar()->addWidget(m_statusLabel, 1);
 
     KStandardAction::quit(qApp, &QApplication::quit, actionCollection());
-    KStandardAction::showMenubar(menuBar(), SLOT(setVisible(bool)), actionCollection());
+    KStandardAction::showMenubar(menuBar(), &QMenuBar::setVisible, actionCollection());
     setStandardToolBarMenuEnabled(true);
     createStandardStatusBarAction();
 
-    connect(KPIM::BroadcastStatus::instance(), SIGNAL(statusMsg(QString)),
-            this, SLOT(slotSetStatusBarText(QString)));
+    connect(KPIM::BroadcastStatus::instance(), &KPIM::BroadcastStatus::statusMsg,
+            this, &MainWindow::slotSetStatusBarText);
 
     connect(qApp, &QCoreApplication::aboutToQuit, this, &MainWindow::slotOnShutdown);
 }
@@ -116,7 +116,7 @@ bool MainWindow::loadPart()
     m_part->setObjectName(QStringLiteral("akregator_part"));
     setCentralWidget(m_part->widget());
 
-    connect(m_part, SIGNAL(setWindowCaption(QString)), this, SLOT(setCaption(QString)));
+    connect(m_part.data(), &Part::setWindowCaption, this, QOverload<const QString &>::of(&KMainWindow::setCaption));
 
     createGUI(m_part);
     browserExtension(m_part)->setBrowserInterface(m_browserIface);
@@ -181,9 +181,10 @@ void MainWindow::optionsConfigureToolbars()
 {
     KConfigGroup grp(KSharedConfig::openConfig().data()->group(autoSaveGroup()));
     saveMainWindowSettings(grp);
-    KEditToolBar dlg(factory());
-    connect(&dlg, &KEditToolBar::newToolBarConfig, this, &MainWindow::applyNewToolbarConfig);
-    dlg.exec();
+    QPointer<KEditToolBar> dlg = new KEditToolBar(factory());
+    connect(dlg.data(), &KEditToolBar::newToolBarConfig, this, &MainWindow::applyNewToolbarConfig);
+    dlg->exec();
+    delete dlg;
 }
 
 // TODO: move to part?
