@@ -81,11 +81,11 @@ Akregator::SelectionController::SelectionController(QObject *parent)
     : AbstractSelectionController(parent)
     , m_feedList()
     , m_feedSelector()
-    , m_articleLister(0)
-    , m_singleDisplay(0)
+    , m_articleLister(nullptr)
+    , m_singleDisplay(nullptr)
     , m_subscriptionModel(new FilterUnreadProxyModel(this))
-    , m_folderExpansionHandler(0)
-    , m_articleModel(0)
+    , m_folderExpansionHandler(nullptr)
+    , m_articleModel(nullptr)
     , m_selectedSubscription()
 {
     m_subscriptionModel->setDoFilter(Settings::hideReadFeeds());
