@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -68,7 +68,7 @@ public:
     {
     }
 
-    virtual ~AkregatorConfigHandler()
+    ~AkregatorConfigHandler() override
     {
     }
 
@@ -84,7 +84,7 @@ public:
     {
     }
 
-    virtual ~MailToURLHandlerWebEngine()
+    ~MailToURLHandlerWebEngine() override
     {
     }
 
@@ -100,7 +100,7 @@ public:
     {
     }
 
-    virtual ~ActionURLHandlerWebEngine()
+    ~ActionURLHandlerWebEngine() override
     {
     }
 
