@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ using std::remove;
 
 using namespace Akregator;
 
-URLHandlerWebEngineManager *URLHandlerWebEngineManager::self = 0;
+URLHandlerWebEngineManager *URLHandlerWebEngineManager::self = nullptr;
 
 URLHandlerWebEngineManager::URLHandlerWebEngineManager(QObject *parent)
     : QObject(parent)
